// Default values for the Core Component
const schemaName = 'ans-documents';

const params = {
  includeSections: 'text', 
  excludeSections: 'text',
  feedSize: 'number',
  feedOffset: 'number'
}

const pattern = (key) => {
  const website = key['arc-site'] || 'Arc Site is not defined.'
  const { includeSections, excludeSections, feedOffset, feedSize } = key

  const body = {
    "query":{
       "bool":{
          "must":[
             {
                "term":{
                   "revision.published":"true"
                }
             },
             {
                "nested":{
                   "path":"taxonomy.sections",
                   "query":{
                      "bool":{
                         "must":[
                            {
                               "terms":{
                                  "taxonomy.sections._id":[
                                     includeSections
                                  ]
                               }
                            },
                            {
                               "term":{
                                  "taxonomy.sections._website": website
                               }
                            }
                         ]
                      }
                   }
                }
             }
          ],
          "must_not":[
             {
                "nested":{
                   "path":"taxonomy.sections",
                   "query":{
                      "bool":{
                         "must":[
                            {
                               "terms":{
                                  "taxonomy.sections._id":[
                                     excludeSections
                                  ]
                               }
                            },
                            {
                               "term":{
                                  "taxonomy.sections._website": website
                               }
                            }
                         ]
                      }
                   }
                }
             }
          ]
       }
    }
 }

  const encodedBody = encodeURI(JSON.stringify(body))

  return `/content/v4/search/published?body=${encodedBody}&website=${website}&size=${feedSize}&from=${feedOffset}&sort=display_date:desc`

}

const resolve = (key) => pattern(key)

const source = {
  resolve,
  schemaName,
  params
}

export default source;